==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Modify/Offset/ts/Offset_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>Offset</name>
    <message>
        <source>Distance:</source>
        <translation type="obsolete">Distancia:</translation>
    </message>
    <message>
        <source>Number:</source>
        <translation type="obsolete">Número:</translation>
    </message>
    <message>
        <source>Choose line, arc or circle</source>
        <translation type="obsolete">Elija una línea, un arco o un círculo</translation>
    </message>
    <message>
        <source>Para&amp;llel (with Distance)</source>
        <translation type="obsolete">Para&amp;lelas (con la distancia)</translation>
    </message>
    <message>
        <location filename="../OffsetInit.js" line="+2"/>
        <source>Offset (with Distance)</source>
        <translation>Equidistante (con distancia)</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Offset line, arc, circle or ellipse</source>
        <translation>Desvío línea, arco círculo o elipse</translation>
    </message>
    <message>
        <source>Draw parallel to existing line or concentric arc, circle</source>
        <translation type="vanished">Dibujar un paralelo a una línea existente o un arco o círculo concéntrico</translation>
    </message>
    <message>
        <location filename="../Offset.ui" line="+17"/>
        <source>&amp;Distance:</source>
        <translation>&amp;Distancia:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Number:</source>
        <translation>&amp;Número:</translation>
    </message>
    <message>
        <source>Choose line, arc, circle, ellipse or spline</source>
        <translation type="vanished">Elija línea, arco, círculo o elipse</translation>
    </message>
    <message>
        <location filename="../Offset.js" line="+75"/>
        <source>Choose line, arc, circle or ellipse</source>
        <translation>Elija línea, arco, círculo o elipse</translation>
    </message>
    <message>
        <location line="+89"/>
        <source>Radius dropped below 0.0 after %1 concentric circle(s).</source>
        <translation>Radio caído por debajo de 0,0 después %1 de círculos concéntricos.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Radius dropped below 0.0 after %1 concentric arc(s).</source>
        <translation>Radio caído por debajo de 0,0 después %1 de arcos concéntricos.</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Modify/Offset/ts/Offset_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>Offset</name>
    <message>
        <source>Distance:</source>
        <translation type="obsolete">Distancia:</translation>
    </message>
    <message>
        <source>Number:</source>
        <translation type="obsolete">Número:</translation>
    </message>
    <message>
        <source>Choose line, arc or circle</source>
        <translation type="obsolete">Elija una línea, un arco o un círculo</translation>
    </message>
    <message>
        <source>Para&amp;llel (with Distance)</source>
        <translation type="obsolete">Para&amp;lelas (con la distancia)</translation>
    </message>
    <message>
        <location filename="../OffsetInit.js" line="+2"/>
        <source>Offset (with Distance)</source>
        <translation>Equidistante (con distancia)</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Offset line, arc, circle or ellipse</source>
        <translation>Desvío línea, arco círculo o elipse</translation>
    </message>
    <message>
        <source>Draw parallel to existing line or concentric arc, circle</source>
        <translation type="vanished">Dibujar un paralelo a una línea existente o un arco o círculo concéntrico</translation>
    </message>
    <message>
        <location filename="../Offset.ui" line="+17"/>
        <source>&amp;Distance:</source>
        <translation>&amp;Distancia:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Number:</source>
        <translation>&amp;Número:</translation>
    </message>
    <message>
        <source>Choose line, arc, circle, ellipse or spline</source>
        <translation type="vanished">Elija línea, arco, círculo o elipse</translation>
    </message>
    <message>
        <location filename="../Offset.js" line="+75"/>
        <source>Choose line, arc, circle or ellipse</source>
        <translation>Elija línea, arco, círculo o elipse</translation>
    </message>
    <message numerus="yes">
        <location line="+89"/>
        <source>Radius dropped below 0.0 after %n concentric circle(s).</source>
        <translation>
            <numerusform>Radio caído por debajo de 0,0 después %n de círculo concéntrico.</numerusform>
            <numerusform>Radio caído por debajo de 0,0 después %n de círculos concéntricos.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+3"/>
        <source>Radius dropped below 0.0 after %n concentric arc(s).</source>
        <translation>
            <numerusform>Radio caído por debajo de 0,0 después %n arco concéntrico.</numerusform>
            <numerusform>Radio caído por debajo de 0,0 después %n de arcos concéntricos.</numerusform>
        </translation>
    </message>
    <message>
        <source>Radius dropped below 0.0 after %1 concentric circle(s).</source>
        <translation type="vanished">Radio caído por debajo de 0,0 después %1 de círculos concéntricos.</translation>
    </message>
    <message>
        <source>Radius dropped below 0.0 after %1 concentric arc(s).</source>
        <translation type="vanished">Radio caído por debajo de 0,0 después %1 de arcos concéntricos.</translation>
    </message>
</context>
</TS>
